tinyMCE.addI18n('cs.fullpage_dlg',{
title:"Vlastnosti dokumentu",
meta_tab:"Hlavn\u00ED",
appearance_tab:"Vzhled",
advanced_tab:"Pokro\u010Dil\u00E9",
meta_props:"Meta informace",
langprops:"Jazyk a k\u00F3dov\u00E1n\u00ED",
meta_title:"Titulek",
meta_keywords:"Kl\u00ED\u010Dov\u00E1 slova",
meta_description:"Popis",
meta_robots:"Roboti",
doctypes:"Doctype",
langcode:"K\u00F3d jazyka",
langdir:"Sm\u011Br textu",
ltr:"Zleva doprava",
rtl:"Zprava doleva",
xml_pi:"XML deklarace",
encoding:"K\u00F3dov\u00E1n\u00ED",
appearance_bgprops:"Vlastnosti pozad\u00ED",
appearance_marginprops:"Okraje t\u011Bla dokumentu",
appearance_linkprops:"Vlastnosti odkaz\u016F",
appearance_textprops:"Vlastnosti textu",
bgcolor:"Barva pozad\u00ED",
bgimage:"Obr\u00E1zek pozad\u00ED",
left_margin:"Lev\u00FD okraj",
right_margin:"Prav\u00FD okraj",
top_margin:"Horn\u00ED okraj",
bottom_margin:"Spodn\u00ED okraj",
text_color:"Barva textu",
font_size:"Velikost p\u00EDsma",
font_face:"Typ p\u00EDsma",
link_color:"Barva odkazu",
hover_color:"Barva p\u0159i zvolen\u00ED",
visited_color:"Barva po zvolen\u00ED",
active_color:"Aktivn\u00ED barva",
textcolor:"Barva",
fontsize:"Velikost fontu",
fontface:"Rodina font\u016F",
meta_index_follow:"Indexovat a sledovat odkazy",
meta_index_nofollow:"Indexovat a nesledovat odkazy",
meta_noindex_follow:"Neindexovat ale sledovat odkazy",
meta_noindex_nofollow:"Neindexovat a nesledovat odkazy",
appearance_style:"Vlastnosti styl\u016F",
stylesheet:"Stylopis",
style:"Styl",
author:"Autor",
copyright:"Copyright",
add:"P\u0159idat nov\u00FD element",
remove:"Odebrat ozna\u010Den\u00FD element",
moveup:"P\u0159esu\u0148 ozna\u010Den\u00FD element v\u00FD\u0161",
movedown:"P\u0159esu\u0148 ozna\u010Den\u00FD element n\u00ED\u017E",
head_elements:"Hlavi\u010Dky",
info:"Informace",
add_title:"Titulek",
add_meta:"Meta element",
add_script:"Skript",
add_style:"Element stylu",
add_link:"Element odkazu",
add_base:"Z\u00E1kladn\u00ED element",
add_comment:"Element koment\u00E1\u0159e",
title_element:"Title element",
script_element:"Element skriptu",
style_element:"Element stylu",
base_element:"Z\u00E1kladn\u00ED element",
link_element:"Element odkazu",
meta_element:"Meta element",
comment_element:"Element koment\u00E1\u0159e",
src:"Src",
language:"Jazyk",
href:"Href",
target:"Target",
type:"Type",
charset:"Znakov\u00E1 sada",
defer:"Defer",
media:"Media",
properties:"Vlastnosti",
name:"N\u00E1zev",
value:"Hodnota",
content:"Obsah",
rel:"Rel",
rev:"Rev",
hreflang:"Href lang",
general_props:"Hlavn\u00ED",
advanced_props:"Pokro\u010Dil\u00E9"
});