tinyMCE.addI18n('sc.fullpage_dlg',{
title:"\u6587\u6863\u5C5E\u6027",
meta_tab:"\u57FA\u672C",
appearance_tab:"\u5916\u89C2",
advanced_tab:"\u9AD8\u7EA7",
meta_props:"\u5C5E\u6027",
langprops:"\u8BED\u8A00\u5C5E\u6027",
meta_title:"\u6807\u9898",
meta_keywords:"\u5173\u952E\u8BCD",
meta_description:"\u5185\u5BB9\u8BF4\u660E",
meta_robots:"\u673A\u5668\u4EBA",
doctypes:"\u6587\u6863\u7C7B\u578B",
langcode:"\u8BED\u8A00\u7F16\u7801",
langdir:"\u8BED\u8A00\u4E66\u5199\u65B9\u5411",
ltr:"\u4ECE\u5DE6\u5230\u53F3",
rtl:"\u4ECE\u53F3\u5230\u5DE6",
xml_pi:"XML\u58F0\u660E",
encoding:"\u5B57\u7B26\u7F16\u7801",
appearance_bgprops:"\u80CC\u666F\u5C5E\u6027",
appearance_marginprops:"\u8FB9\u8DDD",
appearance_linkprops:"\u94FE\u63A5\u989C\u8272",
appearance_textprops:"\u6587\u5B57\u5C5E\u6027",
bgcolor:"\u80CC\u666F\u989C\u8272",
bgimage:"\u80CC\u666F\u56FE\u7247",
left_margin:"\u5DE6\u8FB9\u8DDD",
right_margin:"\u53F3\u8FB9\u8DDD",
top_margin:"\u4E0A\u8FB9\u8DDD",
bottom_margin:"\u4E0B\u8FB9\u8DDD",
text_color:"\u6587\u5B57\u989C\u8272",
font_size:"\u6587\u5B57\u5927\u5C0F",
font_face:"\u5B57\u4F53",
link_color:"\u94FE\u63A5\u989C\u8272",
hover_color:"\u9F20\u6807\u5212\u8FC7\u65F6\u989C\u8272",
visited_color:"\u8BBF\u95EE\u8FC7\u7684\u989C\u8272",
active_color:"\u70B9\u51FB\u65F6\u989C\u8272",
textcolor:"\u6587\u5B57\u989C\u8272",
fontsize:"\u6587\u5B57\u5927\u5C0F",
fontface:"\u5B57\u4F53",
meta_index_follow:"Index and follow the links",
meta_index_nofollow:"Index and don't follow the links",
meta_noindex_follow:"Do not index but follow the links",
meta_noindex_nofollow:"Do not index and don\'t follow the links",
appearance_style:"\u5916\u89C2\u6837\u5F0F",
stylesheet:"\u6837\u5F0F\u8868",
style:"\u6837\u5F0F",
author:"\u4F5C\u8005",
copyright:"\u7248\u6743",
add:"\u6DFB\u52A0",
remove:"\u5220\u9664",
moveup:"\u4E0A\u79FB",
movedown:"\u4E0B\u79FB",
head_elements:"\u5934\u5143\u7D20head",
info:"\u4FE1\u606F",
add_title:"\u6DFB\u52A0\u6807\u9898",
add_meta:"\u6DFB\u52A0meta",
add_script:"\u6DFB\u52A0\u811A\u672C",
add_style:"\u6DFB\u52A0\u6837\u5F0F",
add_link:"\u6DFB\u52A0\u94FE\u63A5",
add_base:"\u6DFB\u52A0Base",
add_comment:"\u6DFB\u52A0\u6CE8\u91CA",
title_element:"\u6807\u9898",
script_element:"\u811A\u672C",
style_element:"\u6837\u5F0F",
base_element:"Base",
link_element:"\u94FE\u63A5",
meta_element:"meta",
comment_element:"\u6CE8\u91CA",
src:"\u7F51\u5740src",
language:"\u8BED\u8A00",
href:"\u7F51\u5740Href",
target:"\u76EE\u6807",
type:"\u7C7B\u578B",
charset:"\u5B57\u7B26\u96C6",
defer:"Defer",
media:"\u5A92\u4F53",
properties:"\u5C5E\u6027",
name:"\u540D",
value:"\u503C",
content:"\u5185\u5BB9",
rel:"Rel",
rev:"Rev",
hreflang:"Href\u8BED\u8A00",
general_props:"\u57FA\u672C",
advanced_props:"\u9AD8\u7EA7"
});