tinyMCE.addI18n('ms.fullpage_dlg',{
title:"Alatan dokumen",
meta_tab:"Am",
appearance_tab:"Penglihatan",
advanced_tab:"Lanjutan",
meta_props:"Meta informasi",
langprops:"Bahasa dan enkod",
meta_title:"Tajuk",
meta_keywords:"Kata kunci",
meta_description:"Huraian",
meta_robots:"Robot",
doctypes:"Doctype",
langcode:"Kod bahasa",
langdir:"Arah bahasa",
ltr:"Kiri ke kanan",
rtl:"Kanan ke kiri",
xml_pi:"XML deklarasi",
encoding:"PengKod aksara",
appearance_bgprops:"Alatan latar belakang",
appearance_marginprops:"Ruangan tepi isi kandungan",
appearance_linkprops:"Pautan warna",
appearance_textprops:"Alatan teks",
bgcolor:"Warna latar belakang",
bgimage:"Imej latar belakang",
left_margin:"Ruangan tepi kiri",
right_margin:"Ruangan tepi kanan",
top_margin:"Ruangan tepi atas",
bottom_margin:"Ruangan tepi bawah",
text_color:"Warna teks",
font_size:"Saiz Huruf",
font_face:"Jenis Huruf",
link_color:"Pautan Warna",
hover_color:"Warna di atas",
visited_color:"Warna telah lawat",
active_color:"Warna aktif",
textcolor:"Warna",
fontsize:"Saiz huruf",
fontface:"Keluarga huruf",
meta_index_follow:"Indeks dan ikut pautan",
meta_index_nofollow:"Indeks dan jangan ikut pautan",
meta_noindex_follow:"Jangan indeks tapi ikut pautan",
meta_noindex_nofollow:"Jangan indeks dan ikut pautan",
appearance_style:"Stylesheet dan alatan gaya",
stylesheet:"Stylesheet",
style:"Gaya",
author:"Pengarang",
copyright:"Hakcipta",
add:"Tambah unsur baru",
remove:"Alih unsur yang dipilih",
moveup:"Alih unsur yang dipilih ke atas",
movedown:"Alih unsur yang dipilih ke bawah",
head_elements:"Unsur pembuka",
info:"Informasi",
add_title:"Unsur tajuk",
add_meta:"Unsur meta",
add_script:"Unsur skrip",
add_style:"Unsur gaya",
add_link:"Unsur pautan",
add_base:"Unsur dasar",
add_comment:"Nod komen",
title_element:"Unsur tajuk",
script_element:"Unsur skrip",
style_element:"Unsur gaya",
base_element:"Unsur dasar",
link_element:"Unsur pautan",
meta_element:"Unsur meta",
comment_element:"Komen",
src:"Src",
language:"Bahasa",
href:"Href",
target:"Sasaran",
type:"Jenis",
charset:"Set huruf",
defer:"Menangguhkan",
media:"Media",
properties:"Alatan",
name:"Nama",
value:"Nilai",
content:"Isi kandungan",
rel:"Rel",
rev:"Rev",
hreflang:"Href lang",
general_props:"Am",
advanced_props:"Lanjutan"
});