tinyMCE.addI18n('ch.fullpage_dlg',{
title:"\u6587\u6863\u5C5E\u6027",
meta_tab:"\u4E00\u822C",
appearance_tab:"\u5916\u89C2",
advanced_tab:"\u8FDB\u9636",
meta_props:"Mata\u4FE1\u606F",
langprops:"\u8BED\u8A00\u548C\u7F16\u7801",
meta_title:"\u6807\u9898",
meta_keywords:"\u5173\u952E\u8BCD",
meta_description:"\u8BF4\u660E",
meta_robots:"Robots",
doctypes:"DocType",
langcode:"\u6587\u5B57\u7F16\u7801",
langdir:"\u6587\u5B57\u4E66\u5199\u65B9\u5411",
ltr:"\u4ECE\u5DE6\u5230\u53F3",
rtl:"\u4ECE\u53F3\u5230\u5DE6",
xml_pi:"XML\u58F0\u660E",
encoding:"\u5B57\u7B26\u7F16\u7801",
appearance_bgprops:"\u80CC\u666F\u989C\u8272",
appearance_marginprops:"\u8FB9\u8DDD",
appearance_linkprops:"\u94FE\u63A5\u989C\u8272",
appearance_textprops:"\u6587\u672C\u5C5E\u6027",
bgcolor:"\u80CC\u666F\u989C\u8272",
bgimage:"\u80CC\u666F\u56FE\u7247",
left_margin:"\u5DE6\u8FB9\u8DDD",
right_margin:"\u53F3\u8FB9\u8DDD",
top_margin:"\u4E0A\u8FB9\u8DDD",
bottom_margin:"\u4E0B\u8FB9\u8DDD",
text_color:"\u6587\u5B57\u989C\u8272",
font_size:"\u6587\u5B57\u5927\u5C0F",
font_face:"\u5B57\u4F53",
link_color:"\u94FE\u63A5\u989C\u8272",
hover_color:"Hover\u989C\u8272",
visited_color:"Visited\u989C\u8272",
active_color:"Active\u989C\u8272",
textcolor:"\u989C\u8272\u8272",
fontsize:"\u6587\u5B57\u5927\u5C0F",
fontface:"\u5B57\u4F53",
meta_index_follow:"\u7D22\u5F15\u5E76\u94FE\u63A5",
meta_index_nofollow:"\u7D22\u5F15\u4F46\u4E0D\u94FE\u63A5",
meta_noindex_follow:"\u4E0D\u7D22\u5F15\u4F46\u952E\u63A5",
meta_noindex_nofollow:"\u4E0D\u7D22\u5F15\u4E5F\u4E0D\u94FE\u63A5",
appearance_style:"\u6837\u5F0F\u8868\u5355\u5355\u548C\u6837\u5F0F\u5C5E\u6027",
stylesheet:"\u6837\u5F0F\u8868\u5355",
style:"\u6837\u5F0F",
author:"\u4F5C\u8005",
copyright:"\u7248\u6743\u58F0\u660E",
add:"\u65B0\u589E\u5143\u7D20",
remove:"\u5220\u9664\u9009\u5B9A\u5143\u7D20",
moveup:"\u4E0A\u79FB\u9009\u5B9A\u5143\u7D20",
movedown:"\u4E0B\u79FB\u9009\u5B9A\u5143\u7D20",
head_elements:"Head\u5143\u7D20",
info:"\u4FE1\u606F",
add_title:"Title\u5143\u7D20",
add_meta:"Meta\u5143\u7D20",
add_script:"Script\u5143\u7D20",
add_style:"Style\u5143\u7D20",
add_link:"Link\u5143\u7D20",
add_base:"Base\u5143\u7D20",
add_comment:"Comment node",
title_element:"Title\u5143\u7D20",
script_element:"Script\u5143\u7D20",
style_element:"Style\u5143\u7D20",
base_element:"Base\u5143\u7D20",
link_element:"Link\u5143\u7D20",
meta_element:"Meta\u5143\u7D20",
comment_element:"Comment\u5143\u7D20",
src:"Src",
language:"\u8BED\u8A00",
href:"Href",
target:"\u76EE\u6807",
type:"\u7C7B\u578B",
charset:"\u5B57\u7B26",
defer:"Defer",
media:"\u5F71\u7247",
properties:"\u5C5E\u6027",
name:"\u540D\u79F0",
value:"\u503C",
content:"\u5185\u5BB9",
rel:"Rel",
rev:"Rev",
hreflang:"Href lang",
general_props:"\u4E00\u822C",
advanced_props:"\u8FDB\u9636"
});