tinyMCE.addI18n('cy.fullpage_dlg',{
title:"Priodweddau dogfen",
meta_tab:"Cyffredinol",
appearance_tab:"Ymddangosiad",
advanced_tab:"Uwch",
meta_props:"Gwybodaeth meta",
langprops:"Iaith ac amgodiad",
meta_title:"Teitl",
meta_keywords:"Allweddair",
meta_description:"Disgrifiad",
meta_robots:"Robotau",
doctypes:"Math dogfen",
langcode:"Cod iaith",
langdir:"Cyfeiriad iaith",
ltr:"Chwith i'r dde",
rtl:"De i'r chwith",
xml_pi:"Datganiad XML",
encoding:"Amgodiad nodau",
appearance_bgprops:"Priodweddau cefndir",
appearance_marginprops:"Ymylon corff",
appearance_linkprops:"Lliwiau cysylltau",
appearance_textprops:"Priodweddau testun",
bgcolor:"Lliw cefndir",
bgimage:"Delwedd cefndir",
left_margin:"Ymyl chwith",
right_margin:"Ymyl dde",
top_margin:"Ymyl brig",
bottom_margin:"Ymyl gwaelod",
text_color:"Lliw testun",
font_size:"Maint ffont",
font_face:"Wyneb ffont",
link_color:"Lliw cysylltau",
hover_color:"Lliw hofran",
visited_color:"Lliw ymwelwyd",
active_color:"Lliw actif",
textcolor:"Lliw",
fontsize:"Maint ffont",
fontface:"Teulu ffont",
meta_index_follow:"Mynegeio a ddilyn y cysylltau",
meta_index_nofollow:"Mynegeio a peidio ddilyn y cysylltau",
meta_noindex_follow:"Peidio mynegeio ond ddilyn y cysylltau",
meta_noindex_nofollow:"Peidio mynegeio a peidio ddilyn y cysylltau",
appearance_style:"Priodweddau dalen-arddull ac arddull",
stylesheet:"Dalen-arddull",
style:"Arddull",
author:"Awdur",
copyright:"Hawlfraint",
add:"Ychwanegu elfen newydd",
remove:"Tynnu elfen dewisedig",
moveup:"Symud elfen dewisedig i fyny",
movedown:"Symud elfen dewisedig i lawr",
head_elements:"Elfennau pen",
info:"Gwybodaeth",
add_title:"Elfen teitl",
add_meta:"Elfen meta",
add_script:"Elfen sgript",
add_style:"Elfen arddull",
add_link:"Elfen cyswllt",
add_base:"Elfen sail",
add_comment:"Nod sylw",
title_element:"Elfen teitl",
script_element:"Elfen sgript",
style_element:"Elfen arddull",
base_element:"Elfen sail",
link_element:"Elfen cyswllt",
meta_element:"Elfen meta",
comment_element:"Sylw",
src:"Fynhonell",
language:"Iaith",
href:"Href",
target:"Targed",
type:"Math",
charset:"Set nodau",
defer:"Gohirio",
media:"Cyfryngau",
properties:"Priodweddau",
name:"Enw",
value:"Gwerth",
content:"Cynnwys",
rel:"Perthynas",
rev:"Diwygiad",
hreflang:"Iaith href",
general_props:"Cyfferdinol",
advanced_props:"Uwch"
});