tinyMCE.addI18n('tt.fullpage_dlg',{
title:"\u6A94\u6848\u5C6C\u6027",
meta_tab:"\u57FA\u672C",
appearance_tab:"\u5916\u89C0",
advanced_tab:"\u9032\u968E",
meta_props:"\u4E2D\u7E7C\u8CC7\u6599\u5377\u6A19\u5C6C\u6027",
langprops:"\u8A9E\u8A00",
meta_title:"\u6A19\u984C",
meta_keywords:"\u95DC\u9375\u5B57",
meta_description:"\u5167\u5BB9\u8AAA\u660E",
meta_robots:"\u6A5F\u5668\u4EBA",
doctypes:"DocType",
langcode:"\u8A9E\u8A00\u7DE8\u78BC",
langdir:"\u8A9E\u8A00\u66F8\u5BEB\u65B9\u5411",
ltr:"\u5F9E\u5DE6\u5230\u53F3",
rtl:"\u5F9E\u53F3\u5230\u5DE6",
xml_pi:"XML \u8072\u660E",
encoding:"\u5B57\u5143\u7DE8\u78BC",
appearance_bgprops:"\u80CC\u666F\u5C6C\u6027",
appearance_marginprops:"\u908A\u8DDD",
appearance_linkprops:"\u9023\u7D50\u9854\u8272",
appearance_textprops:"\u6587\u5B57\u5C6C\u6027",
bgcolor:"\u80CC\u666F\u9854\u8272",
bgimage:"\u80CC\u666F\u5716\u7247",
left_margin:"\u5DE6\u908A\u8DDD",
right_margin:"\u53F3\u908A\u8DDD",
top_margin:"\u4E0A\u908A\u8DDD",
bottom_margin:"\u4E0B\u908A\u8DDD",
text_color:"\u6587\u5B57\u9854\u8272",
font_size:"\u6587\u5B57\u5927\u5C0F",
font_face:"\u5B57\u9AD4",
link_color:"\u9023\u7D50\u9854\u8272",
hover_color:"Hover \u9854\u8272",
visited_color:"Visited \u9854\u8272",
active_color:"Active \u9854\u8272",
textcolor:"\u9854\u8272",
fontsize:"\u6587\u5B57\u5927\u5C0F",
fontface:"\u5B57\u9AD4",
meta_index_follow:"Index and follow the links",
meta_index_nofollow:"Index and don't follow the links",
meta_noindex_follow:"Do not index but follow the links",
meta_noindex_nofollow:"Do not index and don\'t follow the links",
appearance_style:"\u6A23\u5F0F\u8868\u5C6C\u6027",
stylesheet:"\u6A23\u5F0F\u8868",
style:"\u6A23\u5F0F",
author:"\u4F5C\u8005",
copyright:"\u7248\u6B0A",
add:"\u65B0\u589E\u6587\u4EF6\u65B0\u7269\u4EF6",
remove:"\u522A\u9664\u9078\u64C7\u7684\u7269\u4EF6",
moveup:"\u5411\u4E0A\u79FB\u52D5\u9078\u64C7\u7684\u7269\u4EF6",
movedown:"\u5411\u4E0B\u79FB\u52D5\u9078\u64C7\u7684\u7269\u4EF6",
head_elements:"\u524D\u982D\u7269\u4EF6",
info:"\u8CC7\u8A0A",
add_title:"\u641C\u5C0B\u7269\u4EF6",
add_meta:"\u5143\u7269\u4EF6",
add_script:"\u8173\u672C\u7269\u4EF6",
add_style:"\u6A23\u5F0F\u7269\u4EF6",
add_link:"\u9023\u7D50\u5316\u7269\u4EF6",
add_base:"Base\u7269\u4EF6",
add_comment:"\u6CE8\u91CB\u7269\u4EF6",
title_element:"\u641C\u5C0B\u7269\u4EF6",
script_element:"\u8173\u672C\u7269\u4EF6",
style_element:"\u6A23\u5F0F\u7269\u4EF6",
base_element:"Base\u7269\u4EF6",
link_element:"\u9023\u7D50\u5316\u7269\u4EF6",
meta_element:"\u5143\u7269\u4EF6",
comment_element:"\u6CE8\u91CB\u7269\u4EF6",
src:"Src",
language:"\u8A9E\u8A00",
href:"Href",
target:"\u76EE\u6A19",
type:"\u985E\u578B",
charset:"\u5B57\u5143\u96C6",
defer:"Defer",
media:"\u5A92\u9AD4",
properties:"\u5C6C\u6027",
name:"\u540D",
value:"\u503C",
content:"\u5167\u5BB9",
rel:"Rel",
rev:"Rev",
hreflang:"Href lang",
general_props:"\u57FA\u672C",
advanced_props:"\u9032\u968E"
});