tinyMCE.addI18n('sk.fullpage_dlg',{
title:"Vlastnosti dokumentu",
meta_tab:"Hlavn\u00E9",
appearance_tab:"Vzh\u013Ead",
advanced_tab:"Roz\u0161\u00EDren\u00E9",
meta_props:"Meta inform\u00E1cie",
langprops:"Jazyk a k\u00F3dovanie",
meta_title:"N\u00E1dpis",
meta_keywords:"K\u013E\u00FA\u010D. slov\u00E1",
meta_description:"Popis",
meta_robots:"Roboty",
doctypes:"Doctype",
langcode:"K\u00F3d jazyka",
langdir:"Smer textu",
ltr:"Z \u013Eava do prava",
rtl:"Z prava do \u013Eava",
xml_pi:"Deklar\u00E1cia XML",
encoding:"Znakov\u00E1 sada",
appearance_bgprops:"Vlastnosti pozadia",
appearance_marginprops:"Odsadenie tela",
appearance_linkprops:"Farba odkazov",
appearance_textprops:"Vlastnosti textu",
bgcolor:"Farba pozadia",
bgimage:"Obr\u00E1zok pozadia",
left_margin:"Odsadenie z \u013Eava",
right_margin:"Odsadenie z prava",
top_margin:"Odsadenie z hora",
bottom_margin:"Odsadenie zo spodu",
text_color:"Farba textu",
font_size:"Ve\u013Ekos\u0165 fontu",
font_face:"Tvar fontu",
link_color:"Farba odkazu",
hover_color:"Farba pri nabehnut\u00ED na odkaz",
visited_color:"Farba nav\u0161t\u00EDven\u00E9ho odkazu",
active_color:"Farba akt\u00EDvneho odkazu",
textcolor:"Farba",
fontsize:"Ve\u013Ekos\u0165 fontu",
fontface:"Rodina fontov",
meta_index_follow:"Index and follow the links",
meta_index_nofollow:"Index and don't follow the links",
meta_noindex_follow:"Do not index but follow the links",
meta_noindex_nofollow:"Do not index and don\'t follow the links",
appearance_style:"Stylesheet and style properties",
stylesheet:"CSS \u0160t\u00FDl",
style:"\u0160t\u00FDl",
author:"Autor",
copyright:"Autorsk\u00E9 pr\u00E1va",
add:"Prida\u0165 nov\u00FD prvok",
remove:"Odstr\u00E1ni\u0165 ozna\u010Den\u00FD prvok",
moveup:"Move selected element up",
movedown:"Move selected element down",
head_elements:"Prvky hlavi\u010Dky",
info:"Inform\u00E1cie",
add_title:"Title element",
add_meta:"Meta element",
add_script:"Script element",
add_style:"Style element",
add_link:"Link element",
add_base:"Base element",
add_comment:"Comment node",
title_element:"Title element",
script_element:"Script element",
style_element:"Style element",
base_element:"Base element",
link_element:"Link element",
meta_element:"Meta element",
comment_element:"Pozn\u00E1mka",
src:"Src",
language:"Jazyk",
href:"Href",
target:"Cie\u013E",
type:"Typ",
charset:"K\u00F3dovanie",
defer:"Defer",
media:"Media",
properties:"Vlastnosti",
name:"N\u00E1zov",
value:"Hodnota",
content:"Content",
rel:"Rel",
rev:"Rev",
hreflang:"Href lang",
general_props:"Hlavn\u00E9",
advanced_props:"Roz\u0161\u00EDren\u00E9"
});