tinyMCE.addI18n('sq.fullpage_dlg',{
title:"Tiparet e dokumentit",
meta_tab:"T\u00EB P\u00EBrgjithshme",
appearance_tab:"Pamja",
advanced_tab:"T\u00EB Avancuara",
meta_props:"Informacioni Meta",
langprops:"Gjuha dhe kodimi",
meta_title:"Titulli",
meta_keywords:"Fjal\u00EBt ky\u00E7e",
meta_description:"P\u00EBrshkrimi",
meta_robots:"Robot\u00EBt",
doctypes:"Doctype",
langcode:"Kodi i gjuh\u00EBs",
langdir:"Drejtimi i gjuh\u00EBs",
ltr:"Majtas-djathtas",
rtl:"Djathtas-majtas",
xml_pi:"Deklarimi XML",
encoding:"Kodimi i karakter\u00EBve",
appearance_bgprops:"Tiparet e fush\u00EBs",
appearance_marginprops:"Hap\u00EBsirat e trupit",
appearance_linkprops:"Ngjyra e lidhjeve",
appearance_textprops:"Tiparet e tekstit",
bgcolor:"Ngjyra e fush\u00EBs",
bgimage:"Foto e fush\u00EBs",
left_margin:"Hap\u00EBsira majtas",
right_margin:"Hap\u00EBsira djathtas",
top_margin:"Hap\u00EBsira n\u00EB krye",
bottom_margin:"Hap\u00EBsira n\u00EB fund",
text_color:"Ngjyra e tekstit",
font_size:"Madh\u00EBsia e g\u00EBrmave",
font_face:"Tipi i g\u00EBrm\u00EBs",
link_color:"Ngjyra e lidhjes",
hover_color:"Ngjyra e hover",
visited_color:"Ngjyra e vizituar",
active_color:"Ngjyra aktive",
textcolor:"Ngjyra",
fontsize:"Madh\u00EBsia e g\u00EBrmave",
fontface:"Tipi i g\u00EBrm\u00EBs",
meta_index_follow:"Indekso dhe ndiq lidhjet",
meta_index_nofollow:"Indekso por mos ndiq lidhjet",
meta_noindex_follow:"Mos indekso por ndiq lidhjet",
meta_noindex_nofollow:"Mos indekso e as mos ndiq lidhjet",
appearance_style:"Faqja e stileve dhe tiparete tyre",
stylesheet:"Faqja e stileve",
style:"Stili",
author:"Autori",
copyright:"T\u00EB drejtat e kopjes",
add:"Shto nj\u00EB element t\u00EB ri",
remove:"Fshi elementin e zgjedhur",
moveup:"L\u00EBviz elementin sip\u00EBr",
movedown:"L\u00EBviz elementin posht\u00EB",
head_elements:"Element\u00EBt e kok\u00EBs",
info:"Informacion",
add_title:"Element titull",
add_meta:"Element meta",
add_script:"Element script",
add_style:"Element stil",
add_link:"Element lidhej",
add_base:"Element baz\u00EB",
add_comment:"Komento",
title_element:"Element titull",
script_element:"Element script",
style_element:"Element stil",
base_element:"Element baz\u00EB",
link_element:"Element lidhje",
meta_element:"Element meta",
comment_element:"Komento",
src:"Src",
language:"Gjuha",
href:"Href",
target:"Sh\u00EBnjestra",
type:"Tipi",
charset:"Charset",
defer:"Defer",
media:"Media",
properties:"Tiparet",
name:"Emri",
value:"Vlera",
content:"P\u00EBrmbajtja",
rel:"Rel",
rev:"Rev",
hreflang:"Href lang",
general_props:"T\u00EB P\u00EBrgjithshme",
advanced_props:"T\u00EB Avancuara"
});