tinyMCE.addI18n('nb.fullpage_dlg',{
title:"Dokumentegenskaper",
meta_tab:"Generelt",
appearance_tab:"Utseende",
advanced_tab:"Avansert",
meta_props:"Metainformasjon",
langprops:"Spr\u00E5k og koding",
meta_title:"Tittel",
meta_keywords:"N\u00F8kkelord",
meta_description:"Beskrivelse",
meta_robots:"Roboter",
doctypes:"Doctype",
langcode:"Spr\u00E5kkode",
langdir:"Skriftretning",
ltr:"Venstre mot h\u00F8yre",
rtl:"H\u00F8yre mot venstre",
xml_pi:"XML-deklarasjon",
encoding:"Tegnkonvertering",
appearance_bgprops:"Bakgrunnsegenskaper",
appearance_marginprops:"Body-marg",
appearance_linkprops:"Lenkefarger",
appearance_textprops:"Tekstegenskaper",
bgcolor:"Bakgrunn",
bgimage:"Bakgrunnsbilde",
left_margin:"Venstre marg",
right_margin:"H\u00F8yre marg",
top_margin:"Toppmarg",
bottom_margin:"Bunnmarg",
text_color:"Farge",
font_size:"Skriftst\u00F8rrelse",
font_face:"Skrifttype",
link_color:"Lenkefarge",
hover_color:"Mus over-farge",
visited_color:"Bes\u00F8kt-farge",
active_color:"Aktive farge",
textcolor:"Farge",
fontsize:"Skriftst\u00F8rrelse",
fontface:"Skrifttype",
meta_index_follow:"Indekser, og f\u00F8lg lenkene",
meta_index_nofollow:"Indekser, men ikke f\u00F8lg lenkene",
meta_noindex_follow:"Ikke indekser, men f\u00F8lg lenkene",
meta_noindex_nofollow:"Ikke indekser, og ikke f\u00F8lg lenkene",
appearance_style:"Stilark og stilegenskaper",
stylesheet:"Stilark",
style:"Stil",
author:"Forfatter",
copyright:"Copyright",
add:"Legg til nytt element",
remove:"Fjern",
moveup:"Flytt markert element opp",
movedown:"Flytt markert element ned",
head_elements:"Overskriftselementer",
info:"Informasjon",
add_title:"Tittelelement",
add_meta:"Metaelement",
add_script:"Skriptelement",
add_style:"Stilelement",
add_link:"Lenkeelement",
add_base:"Basiselement",
add_comment:"Kommentarnode",
title_element:"Tittelelement",
script_element:"Skriptelement",
style_element:"Stilelement",
base_element:"Basiselement",
link_element:"Lenkeelement",
meta_element:"Metaelement",
comment_element:"Kommentar",
src:"Skjerm",
language:"Spr\u00E5k",
href:"Href",
target:"M\u00E5l",
type:"Type",
charset:"Tegnsett",
defer:"Defer",
media:"Objekt",
properties:"Egenskaper",
name:"Navn",
value:"Verdi",
content:"Innhold",
rel:"Sidens forhold til m\u00E5let",
rev:"M\u00E5lets forhold til siden",
hreflang:"Href lang",
general_props:"Generelt",
advanced_props:"Avasert"
});