tinyMCE.addI18n('sl.fullpage_dlg',{
title:"Lastnosti dokumenta",
meta_tab:"Splo\u0161no",
appearance_tab:"Izgled",
advanced_tab:"Napredno",
meta_props:"Meta podatki",
langprops:"Jezik in kodiranje",
meta_title:"Naslov",
meta_keywords:"Klju\u010Dne besede",
meta_description:"Opis",
meta_robots:"Roboti",
doctypes:"Doctype",
langcode:"Koda jezika",
langdir:"Smer pisave",
ltr:"Od leve proti desni",
rtl:"Od desne proti levi",
xml_pi:"Najava XML",
encoding:"Kodiranje znakov",
appearance_bgprops:"Lastnosti ozadja",
appearance_marginprops:"Robovi telesa",
appearance_linkprops:"Barve povezav",
appearance_textprops:"Lastnosti besedila",
bgcolor:"Barva ozadja",
bgimage:"Slika ozadja",
left_margin:"Levi rob",
right_margin:"Desni rob",
top_margin:"Zgornji rob",
bottom_margin:"Spodnji rob",
text_color:"Barva pisave",
font_size:"Velikost pisave",
font_face:"Vrsta pisave",
link_color:"Barva povezave",
hover_color:"Barva nakazane povezave",
visited_color:"Barva obiskane povezave",
active_color:"Barva dejavne povezave",
textcolor:"Barva",
fontsize:"Velikost pisave",
fontface:"Dru\u017Eina pisave",
meta_index_follow:"Indeksiraj in sledi povezavam",
meta_index_nofollow:"Indeksiraj a ne sledi povezavam",
meta_noindex_follow:"Ne indeksiraj a sledi pvoezavams",
meta_noindex_nofollow:"Ne indeksiraj in ne sledi povezavam",
appearance_style:"Lastnosti slogov",
stylesheet:"Slogi",
style:"Slog",
author:"Avtor",
copyright:"Copyright",
add:"Dodaj element",
remove:"Odstrani izbrani element",
moveup:"Premakni izbrani element navzgor",
movedown:"Premakni izbrani element navzdol",
head_elements:"Elementi glave",
info:"Informacija",
add_title:"element Title",
add_meta:"element Meta",
add_script:"element Script",
add_style:"element Style",
add_link:"element Link",
add_base:"element Base",
add_comment:"komentar",
title_element:"element Title",
script_element:"element Script",
style_element:"element Style",
base_element:"element Base",
link_element:"element Link",
meta_element:"element Meta",
comment_element:"komentar",
src:"Src",
language:"Language",
href:"Href",
target:"Target",
type:"Type",
charset:"Charset",
defer:"Defer",
media:"Media",
properties:"Lastnosti",
name:"ime",
value:"vrednost",
content:"vsebina",
rel:"Rel",
rev:"Rev",
hreflang:"Href lang",
general_props:"Splo\u0161no",
advanced_props:"Napredno"
});